#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monoid-subclasses
version:              1.1
visibility:           public
id:                   monoid-subclasses-1.1-AwFjCNwVwkv9V7v1aD1jp3
key:                  monoid-subclasses-1.1-AwFjCNwVwkv9V7v1aD1jp3
license:              BSD-3-Clause
copyright:            (c) 2013-2018 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/monoid-subclasses/
synopsis:             Subclasses of Monoid
description:
    A hierarchy of subclasses of '\''Monoid'\'' together with their instances for all data structures from base, containers, and
    text packages.

category:             Data, Algebra, Text
abi:                  d614a2b322e13c84dc0ff94ef72fcdec
exposed:              True
exposed-modules:
    Data.Monoid.Cancellative Data.Monoid.Factorial Data.Monoid.GCD
    Data.Monoid.Instances.ByteString.UTF8
    Data.Monoid.Instances.CharVector Data.Monoid.Instances.Concat
    Data.Monoid.Instances.Measured Data.Monoid.Instances.Positioned
    Data.Monoid.Instances.Stateful Data.Monoid.Monus Data.Monoid.Null
    Data.Monoid.Textual Data.Semigroup.Cancellative
    Data.Semigroup.Factorial

import-dirs:          /usr/lib/ghc-8.10.5/site-local/monoid-subclasses-1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/monoid-subclasses-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/monoid-subclasses-1.1
hs-libraries:         HSmonoid-subclasses-1.1-AwFjCNwVwkv9V7v1aD1jp3
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    primes-0.2.1.0-HLShIrNBhf0CRMbJsLTsZV text-1.2.4.1
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-monoid-subclasses/html/monoid-subclasses.haddock

haddock-html:         /usr/share/doc/haskell-monoid-subclasses/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

